@@ -1,3 +1,5 @@
+#![deny(missing_debug_implementations)]
+#![deny(missing_docs)]
 mod code_block;
 mod delimiter;
 mod header;
@@ -11,6 +13,6 @@ pub use self::{
     header::Header,
     math::{MathKind, MathNode},
     styled::{StyleKind, StyleNode},
-    text::TextKind,
+    text::TextSpan,
 };
 use super::*;
