@@ -2,15 +2,16 @@ use super::*;
 
 mod detailed;
 mod item;
+mod ordered;
+mod orderless;
 mod prefix;
 
-pub use self::{detailed::DetailedList, item::ListItem, prefix::ListPrefixSymbol};
+pub use self::{detailed::DetailedList, item::ListItem, ordered::OrderedList, orderless::OrderlessList, prefix::ListPrefixSymbol};
 
 #[derive(Clone, Eq, PartialEq, Hash)]
-pub struct ListView {
-    pub ignore_global_list_style: bool,
-    pub first_symbol: ListPrefixSymbol,
-    pub children: Vec<ListItem>,
+pub enum ListView {
+    Ordered(Box<OrderedList>),
+    Orderless(Box<OrderlessList>),
 }
 
 impl ListView {
@@ -25,7 +26,8 @@ impl ListView {
     /// ```
     #[inline]
     pub fn ordered_list(children: Vec<ListItem>) -> Self {
-        Self { ignore_global_list_style: false, first_symbol: ListPrefixSymbol::Hyphen, children }
+        let list = OrderedList { first_order: 0, children };
+        Self::Ordered(box list)
     }
     /// ## Orderless List
     /// ```note
@@ -38,7 +40,8 @@ impl ListView {
     /// ```
     #[inline]
     pub fn orderless_list(children: Vec<ListItem>) -> Self {
-        Self { ignore_global_list_style: false, first_symbol: ListPrefixSymbol::Arabic, children }
+        let list = OrderlessList { children };
+        Self::Orderless(box list)
     }
 }
 
