@@ -37,16 +37,34 @@ macro_rules! into_node_boxed {
         }
     }
     };
+    ($t:ty |> $name:ident) => {
+    impl Into<ASTKind> for $t {
+        #[inline]
+        fn into(self) -> ASTKind { ASTKind::$name(self) }
+    }
+    impl Into<ASTNode> for $t {
+        #[inline]
+        fn into(self) -> ASTNode { ASTKind::$name(self).into_node(None) }
+    }
+    impl IntoASTNode for $t {
+        #[inline]
+        fn into_node(self, range: MaybeRanged) -> ASTNode {
+            ASTKind::$name(self).into_node(range)
+        }
+    }
+    };
     ($($t:ty => $name:ident),+ $(,)?) => (
         $(into_node_boxed!($t=>$name);)+
     );
+    ($($t:ty |> $name:ident),+ $(,)?) => (
+        $(into_node_boxed!($t|>$name);)+
+    );
 }
 
 into_node_boxed![
     QuoteBlock => QuoteNode,
     Header     => Header,
     Delimiter  => Delimiter,
-    ListView   => ListView,
     CodeNode   => CodeNode ,
     MathNode   => MathNode,
     TextSpan   => TextSpan,
@@ -54,3 +72,8 @@ into_node_boxed![
     Command    => Command,
     Value      => Value,
 ];
+
+into_node_boxed![
+    ListView   |> ListView,
+    TableView  |> TableView,
+];
